Architecture
============

This section provides detailed information about the PyEye Server architecture.

.. toctree::
   :maxdepth: 2

   overview
   plugin-system
   caching-strategy
   project-management
   performance
